@@ -64,13 +64,13 @@ class GBMFitter:
             - feature_selection: the threshold to select features. If -1, takes all"""
 
         # Fits the data for each library algorithm
-        if skip_CB == False:
+        if not skip_CB:
             self._fit('CB', X, y, categorical, feature_selection)
 
-        if skip_XGB == False:
+        if not skip_XGB:
             self._fit('XGB', X, y, categorical, feature_selection)
 
-        if skip_LGB == False:
+        if not skip_LGB:
             self._fit('LGB', X, y, categorical, feature_selection)
 
     def _fit(self, library, X, y, categorical=[], feature_selection=-1):
@@ -165,7 +165,8 @@ class GBMFitter:
                          early_stopping=early_stopping,
                          eval_set=cb.Pool(data=X_val,
                                           label=y_val,
-                                          cat_features=self._get_categorical_index(X_train, categorical)) if early_stopping else None)
+                                          cat_features=self._get_categorical_index(X_train, categorical)) if early_stopping else None,
+                         verbose_eval=False)
             y_pred_train = m.predict(X_train)
             y_pred_val = m.predict(X_val)
 
@@ -174,7 +175,8 @@ class GBMFitter:
                           dtrain=xgb.DMatrix(X_train, y_train),
                           num_boost_round=num_boost_rounds,
                           early_stopping_rounds=early_stopping,
-                          evals=[(xgb.DMatrix(X_train, y_train), 'Validation')],
+                          evals=[(xgb.DMatrix(X_train, y_train), 'Validation')] if early_stopping else None,
+                          verbose_eval=False,
                           obj=obj)
             y_pred_train = m.predict(xgb.DMatrix(X_train))
             y_pred_val = m.predict(xgb.DMatrix(X_val))
@@ -197,7 +199,8 @@ class GBMFitter:
                           valid_sets=[lgb.Dataset(X_val,
                                                  label=y_val,
                                                  free_raw_data=False)] if early_stopping else None,
-                          valid_names=['Validation'] if early_stopping else None
+                          valid_names=['Validation'] if early_stopping else None,
+                          verbose_eval=False,
                           )
             # Predict validation dataset to get train result and OOF validation result
             y_pred_train = m.predict(X_train)
